.. _all-salt.pillars:

===================================
Full list of builtin pillar modules
===================================

.. currentmodule:: salt.pillar

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cmd_json
    cmd_yaml
    cmd_yamlex
    cobbler
    django_orm
    etcd_pillar
    foreman
    git_pillar
    hiera
    libvirt
    mongo
    mysql
    pillar_ldap
    puppet
    reclass_adapter
    redismod
    s3
    svn_pillar
    virtkey
